@@ -1,28 +1,17 @@
-import os
 import inspect
 import json
-import datetime
 from collections import OrderedDict
 import warnings
-import sys
 import logging
-import boto3
-from boto3.session import Session
-import asyncio
-from slack import WebClient
-from slack.errors import SlackApiError
-from pathlib import Path
 from joblib import dump
 
 from Accuinsight.modeler.core import func, path, get
 from Accuinsight.modeler.core.func import get_time
-from Accuinsight.modeler.core.get_for_visual import roc_pr_curve, get_visual_info_regressor, get_true_y, get_visual_info_regressor
-from Accuinsight.modeler.utils.runs_utils import get_aws_info, ProgressPercentage
+from Accuinsight.modeler.core.get_for_visual import roc_pr_curve, get_true_y, get_visual_info_regressor
 from Accuinsight.modeler.core.sklearnModelType import REGRESSION, CLASSIFICATION
 from Accuinsight.modeler.core.LcConst.LcConst import ALL_MODEL_PARAMS, SELECTED_PARAMS, SELECTED_METRICS, VALUE_ERROR, \
-    LOGGING_TIME, LOGGING_RUN_ID, FITTED_MODEL, RUN_PREFIX_PATH, RUN_MODEL_JSON_PATH, RUN_MODEL_VISUAL_JSON_PATH, \
-    RUN_MODEL_HOME_PATH, ENV_JUPYTER_HOME_DIR
-from Accuinsight.modeler.core.Run.RunInfo.RunInfo import set_current_runs, clear_runs, print_run_info, \
+    LOGGING_TIME, LOGGING_RUN_ID, FITTED_MODEL
+from Accuinsight.modeler.core.Run.RunInfo.RunInfo import set_current_runs, clear_runs, \
     set_git_meta, set_python_dependencies, set_run_name, set_model_json_path, set_visual_json_path, set_model_file_path, set_prefix_path, set_best_model_joblib_path, _set_result_path, set_shap_json_path
 from Accuinsight.modeler.utils.dependency.dependencies import gather_sources_and_dependencies
 from Accuinsight.modeler.core.LcConst import LcConst
@@ -31,7 +20,7 @@ from Accuinsight.modeler.clients.modeler_api import LifecycleRestApi
 
 from Accuinsight.modeler.core.feature_contribution import shap_value
 from Accuinsight.modeler.core import metricsLightgbm
-
+from Accuinsight.Lifecycle.common import Common
 
 logging.basicConfig(level=logging.INFO,
                     format='%(message)s')
@@ -39,83 +28,13 @@ logging.basicConfig(level=logging.INFO,
 warnings.filterwarnings("ignore")
 
 
-class accuinsight(object):
+class accuinsight(Common):
     def __init__(self):
-        self.BucketInfo = None
-        self.endpoint = None
-        
-
-    def get_file(self, aws_json_file_name):
-        global save_path, target_name, bucket_info
-        
-        # meta file 저장하는 폴더 만들면, 이 경로는 수정돼야 함.
-        aws_info_json_path = os.path.join(ENV_JUPYTER_HOME_DIR, aws_json_file_name)
-    
-        with open(aws_info_json_path) as jsonFile:
-            self.BucketInfo = json.load(jsonFile)
-            
-        BUCKET_TYPE = self.BucketInfo['bucketType']
-        BUCKET_NAME = self.BucketInfo['bucketName']
-        FILE_PATH = self.BucketInfo['filePath']
-        FILE_NAME = self.BucketInfo['fileName']
-        #FILE_TYPE = self.BucketInfo['fileType']
-        #FILE_DELIM = self.BucketInfo['fileDelim']
-        ACCESS_KEY = self.BucketInfo['myAccessKey']
-        SECRET_KEY = self.BucketInfo['mySecretKey']
-        REGION = self.BucketInfo['region']
-        URL = self.BucketInfo['endpoint']
-        
-        ## define the target name
-        target_name = self.BucketInfo['target']
-
-        ## path for saving data
-        save_dir = os.path.join(ENV_JUPYTER_HOME_DIR, 'data_from_AWS')
-
-        if os.path.exists(save_dir) == False:
-            os.mkdir(save_dir)
-        else:
-            pass
-  
-        self.save_file_name = FILE_NAME.split('.')[0] + '_' + str(datetime.datetime.now().date()).replace('-', '') + '.' + FILE_NAME.split('.')[1]
-        save_path = os.path.join(save_dir, self.save_file_name)
-
-        # endpoint
-        pre_url = 'https://' + BUCKET_NAME + '.' + URL
-        self.endpoint = os.path.join(pre_url, FILE_PATH)
-
-        client = boto3.client(BUCKET_TYPE,
-                              aws_access_key_id=ACCESS_KEY,
-                              aws_secret_access_key=SECRET_KEY,
-                              region_name=REGION)
-
-        transfer = boto3.s3.transfer.S3Transfer(client)
-
-        progress = ProgressPercentage(client, BUCKET_NAME, FILE_PATH)
-
-        sys.stdout.write('%s %s %s' % ('Downloading file...', FILE_NAME, '\n'))
-        transfer.download_file(BUCKET_NAME, FILE_PATH, save_path, callback=progress)
-        logging.info(save_path)
-        
-        bucket_info = self.BucketInfo
-    
-    def set_slack(self, token = None, channel_id = None):
-        self.token = token
-        self.channel_id = channel_id
-
-    def send_message(self, message = None):
-        if message is not None:
-            try:
-                message = message
-                response = WebClient(token=self.token).chat_postMessage(channel=self.channel_id, text=message)
-            except SlackApiError as e:
-                assert e.response["error"]
-        else:
-            raise ValueError('message를 입력해주세요.')
-
+        super(Common, self).__init__()
 
     class add_experiment(object):
         def __init__(self, model_name, *args, model_monitor=False):
-            if model_monitor == True:
+            if model_monitor:
                 self.shap_on = True
                 logging.info('Using add_experiment(model_monitor=True)')
             else:
@@ -124,8 +43,8 @@ class accuinsight(object):
             
             self.model_name = model_name
         
-            is_notebook = is_in_ipython()
-            if is_notebook == True:
+            # if in notebook
+            if is_in_ipython():
                 self.var_model_file_path = get_current_notebook()
                 _caller_globals = inspect.stack()[1][0].f_globals
                 (
@@ -173,14 +92,12 @@ class accuinsight(object):
     
             else:
                 raise ValueError('Check the arguments of function - add_experiment(model_name, X_val, y_val) or add_experiment(model_name, X_train, y_train, X_val, y_val)')
-
             
             # sklearn/xgboost/lightgbm
             get_from_model = get.from_model(self.model_name)
             self.all_model_params = get_from_model.all_params()
             self.model_param_keys = get_from_model.param_keys()
             
-            
             # classifier
             if any(i in self.fitted_model for i in CLASSIFICATION):
                 self.vis_info = roc_pr_curve(self.model_name, self.xval, self.yval)
@@ -220,7 +137,7 @@ class accuinsight(object):
             set_prefix_path(self.dict_path[LcConst.RUN_PREFIX_PATH])
             set_run_name(self.fitted_model, self.summary_info[LOGGING_RUN_ID])
 
-            return(self)
+            return self
 
         def __exit__(self, a, b, c):
             self.summary_info[ALL_MODEL_PARAMS] = self.all_model_params
@@ -231,9 +148,9 @@ class accuinsight(object):
             # model_monitor = True
             self.run_id = self.summary_info[LOGGING_RUN_ID]
             
-            if self.shap_on == True:
+            if self.shap_on:
                 try:
-                    self.feature_name = get.feature_name(save_path, bucket_info, target_name)
+                    self.feature_name = get.feature_name(self.save_path, self.StorageInfo, self.target_name)
                 except:
                     self.feature_name = None
                 self.run_id = self.fitted_model + '-' + self.run_id
@@ -305,13 +222,12 @@ class accuinsight(object):
                                             env_value[LcConst.BACK_END_API_URI])
             modeler_rest.lc_create_run()
 
-
         def log_params(self, param = None):
             # sklearn/xgboost/lightgbm
             if param:
                 
                 if param in self.model_param_keys:
-                    return(self.selected_params.append(param))
+                    return self.selected_params.append(param)
 
                 else:
                     self.error_log.append(True)
@@ -322,4 +238,3 @@ class accuinsight(object):
 
         def log_tag(self, description):
             self.summary_info['tag'] = description
-
