@@ -1,17 +1,10 @@
 import inspect
 import json
 import warnings
-import os
-import re
 from collections import OrderedDict
 import gorilla
-import sys
 import logging
-import boto3
-from pathlib import Path
 import numpy as np
-from slack_sdk import WebClient
-from slack_sdk.errors import SlackApiError
 import keras
 from keras.callbacks import CSVLogger
 from Accuinsight.modeler.core import func, path, get
@@ -19,19 +12,22 @@ from Accuinsight.modeler.core.func import get_time
 from Accuinsight.modeler.core.LcConst import LcConst
 from Accuinsight.modeler.core.LcConst.LcConst import RUN_NAME_KERAS
 from Accuinsight.modeler.core.get_for_visual import roc_pr_curve, get_visual_info_regressor
-from Accuinsight.modeler.core.Run.RunInfo.RunInfo import set_current_runs, clear_runs, set_model_json_path, set_visual_csv_path, set_visual_json_path, set_best_model_h5_path, set_best_model_json_path, print_run_info, set_git_meta, set_python_dependencies, set_run_name, set_model_file_path, set_prefix_path
+from Accuinsight.modeler.core.Run.RunInfo.RunInfo import set_current_runs, clear_runs, set_model_json_path, \
+    set_visual_csv_path, set_visual_json_path, set_best_model_h5_path, set_best_model_json_path, \
+    set_python_dependencies, set_run_name, set_model_file_path, set_prefix_path
 from Accuinsight.modeler.utils.dl_utils import delete_files_except_best, get_best_model_path
-from Accuinsight.modeler.utils.runs_utils import get_aws_info, ProgressPercentage
 from Accuinsight.modeler.utils.dependency.dependencies import gather_sources_and_dependencies
 from Accuinsight.modeler.utils.os_getenv import is_in_ipython, get_current_notebook, get_os_env
 from Accuinsight.modeler.clients.modeler_api import LifecycleRestApi
+from Accuinsight.Lifecycle.common import Common
 
 logging.basicConfig(level=logging.INFO,
                     format='%(message)s')
 
 warnings.filterwarnings("ignore")
 
-class accuinsight(object):
+
+class accuinsight(Common):
     def __init__(self):
         self.BucketInfo = None
         self.endpoint = None
@@ -40,65 +36,7 @@ class accuinsight(object):
         self.channel_id = None
         self.message = None
 
-    def get_file(self, sub_path):
-        self.BucketInfo = get_aws_info(sub_path)
-        BUCKET_TYPE = self.BucketInfo['bucket_type']
-        BUCKET_NAME = self.BucketInfo['bucket_name']
-        FILE_PATH = self.BucketInfo['file_path']
-        FILE_NAME = self.BucketInfo['file_name']
-        FILE_TYPE = self.BucketInfo['file_type']
-        FILE_DELIM = self.BucketInfo['file_delim']
-        ACCESS_KEY = self.BucketInfo['my_access_key']
-        SECRET_KEY = self.BucketInfo['my_secret_key']
-        REGION = self.BucketInfo['region']
-        URL = self.BucketInfo['endpoint']
-
-        ## path for saving data
-        save_dir = os.path.join(Path.home(), 'data_from_catalog')
-        if os.path.exists(save_dir) == False:
-            os.mkdir(save_dir)
-        else:
-            pass
-        
-        save_path = os.path.join(str(Path.home()), save_dir, FILE_NAME)
-        
-        # endpoint (수정)
-        #pre_url = 'https://' + BUCKET_NAME + '.' + URL
-        #self.endpoint = os.path.join(pre_url, FILE_PATH)
-
-        ### data catalog 사용시
-        # https://accuinsight-dev.cloudz.co.kr/datacatalog/#/management/table/detail/24/156
-        # '/databases/24/tables/156'
-
-        regex = re.compile('(\d+)/tables/(\d+)')
-        host = 'https://accuinsight-dev.cloudz.co.kr/datacatalog/#/management/table/detail'
-        self.endpoint = os.path.join(host, regex.search(sub_path).group(1), regex.search(sub_path).group(2))
-        
-        client = boto3.client(BUCKET_TYPE,
-                              aws_access_key_id = ACCESS_KEY,
-                              aws_secret_access_key = SECRET_KEY,
-                              region_name = REGION)
-
-        transfer = boto3.s3.transfer.S3Transfer(client)
-               
-        progress = ProgressPercentage(client, BUCKET_NAME, FILE_PATH)
-
-        sys.stdout.write('%s %s %s' % ('Downloading file...', FILE_NAME,  '\n'))
-        transfer.download_file(BUCKET_NAME, FILE_PATH, save_path, callback=progress)
-        logging.info(save_path)
-        
-    def set_slack(self, token = None, channel_id = None):
-        self.token = token
-        self.channel_id = channel_id
-
-    def send_message(self, message = None, thresholds = None):
-        if message is not None and thresholds is not None:
-            raise ValueError("'message'와 'thresholds' 두 개의 arguments를 동시에 입력할 수 없습니다.")
-        else:
-            self.message = message
-            self.thresholds = thresholds
-
-    def autolog(self, tag = None, best_weights = False):
+    def autolog(self, tag=None, best_weights=False):
         global description, endpoint, var_model_file_path, message, thresholds, token, channel_id
         description = tag
         endpoint = self.endpoint
@@ -106,14 +44,13 @@ class accuinsight(object):
         thresholds = self.thresholds
         token = self.token
         channel_id = self.channel_id
-        if best_weights == True:
+        if best_weights:
             best_weights_on = True
         else:
             best_weights_on = False
 
-        
-        is_notebook = is_in_ipython()
-        if is_notebook == True:
+        # if in notebook
+        if is_in_ipython():
             var_model_file_path = get_current_notebook()
             _caller_globals = inspect.stack()[1][0].f_globals
             (
@@ -135,16 +72,18 @@ class accuinsight(object):
                 save_git_info=True
             )
             var_model_file_path = mainfile['filename']
-
     
         class TrainHistoryCallbacks(keras.callbacks.Callback):
-            def __init__(self, verbose = 1, mode = 'auto', period = 1):
+            def __init__(self, verbose=1, mode='auto', period=1):
                 super(TrainHistoryCallbacks, self).__init__()
                 self.verbose = verbose
                 self.period = period
                 self.best_epochs = 0
                 self.epochs_since_last_save = 0
                 self.mode = mode
+                self.model_summary = OrderedDict()
+                self.run_id = None
+                self.model_type = None
         
             def on_train_begin(self, logs={}):
                 if best_weights_on:
@@ -156,7 +95,7 @@ class accuinsight(object):
                 start = get_time.now()
                 self.run_id = func.get_run_id()
                 self.model_type = get.model_type(self.model)
-                self.model_summary = OrderedDict()
+
                 self.model_summary['data_version'] = endpoint
                 self.model_summary['model_description'] = description
                 self.model_summary['logging_time'] = get_time.logging_time()
@@ -169,8 +108,7 @@ class accuinsight(object):
                     self.model_summary['loss_function'] = self.model.loss
                 
                 self.model_summary['optimizer_info'] = {type(self.model.optimizer).__name__: self.model.optimizer.get_config()}
-            
-            
+
                 '''[get best model] on_train_begin '''
                 self.best_weights = self.model.get_weights()
               
@@ -315,19 +253,18 @@ class accuinsight(object):
                 set_best_model_json_path(path_for_setting_model_json)
                 path_for_setting_model_h5 = self.dict_path['save_model_dir'] + get_best_model_path(run_id = self.run_id, path = self.dict_path)['h5']
                 set_best_model_h5_path(path_for_setting_model_h5)
-            
-            
+
                 start_ts = int(start.timestamp())
                 end_ts = int(end.timestamp())
                 delta_ts = end_ts - start_ts
             
                 clear_runs(start_ts, end_ts, delta_ts)
-                accuinsight._send_message(metric = self.monitor,
-                                          current_value = self.current_value,
-                                          message = self.message,
-                                          thresholds = self.thresholds,
-                                          token = self.token,
-                                          channel_id = self.channel_id)
+                accuinsight._send_message(metric=self.monitor,
+                                          current_value=self.current_value,
+                                          message=self.message,
+                                          thresholds=self.thresholds,
+                                          token=self.token,
+                                          channel_id=self.channel_id)
                 env_value = get_os_env('ENV')
                 modeler_rest = LifecycleRestApi(env_value[LcConst.BACK_END_API_URL],
                                                 env_value[LcConst.BACK_END_API_PORT],
@@ -335,14 +272,13 @@ class accuinsight(object):
                 modeler_rest.lc_create_run()
                 accuinsight.off_autolog()
 
-                
         class visualCallbacks(keras.callbacks.Callback):
             def __init__(self, x_validation=None, y_validation=None):
+                super(visualCallbacks, self).__init__()
                 self.x_val = x_validation
                 self.y_val = y_validation
 
             def on_train_end(self, logs={}):
-
                 self.dict_path = path.get_file_path(self.model, usedFramework='keras')
 
                 # path for visual.json
@@ -367,7 +303,6 @@ class accuinsight(object):
                         json.dump(visual_regression_json, save_file, indent="\t")
             
         def run_and_log_function(self, original, args, kwargs, unlogged_params):
-
             dict_path = path.get_file_path(self, usedFramework='keras')
         
             path_for_setting_visual_csv = dict_path['visual_csv']
@@ -436,48 +371,6 @@ class accuinsight(object):
         gorilla.apply(gorilla.Patch(keras.Model, 'fit', fit, settings=settings))
 
 
-    def _send_message(metric=None, current_value=None, message=None, thresholds=None, token=None, channel_id=None):
-        
-        logger = logging.getLogger(__name__)
-        
-        if token is not None and channel_id is not None:
-        
-            if thresholds is not None:
-                try:
-                    if current_value >= thresholds:
-                        msg = '[모델 학습 완료] ' + metric + '이 설정하신 thresolds: ' + str(thresholds) + '를 초과하였습니다.'
-                        response = WebClient(token=token).chat_postMessage(channel=channel_id, text=msg)
-                except SlackApiError as e:
-                    logger.error(f"Error message: {e}")
-                    
-            elif message is not None:
-                try:
-                    msg = message
-                    response = WebClient(token=token).chat_postMessage(channel=channel_id, text=msg)
-                except SlackApiError as e:
-                    logger.error(f"Error message: {e}")
-        else:
-            pass
-
-
-#    def _send_message(metric = None, current_value = None, message = None, thresholds=None, token = None, channel_id = None):
-#        if token is not None and channel_id is not None:
-#            if thresholds is not None:
-#                try:
-#                    if current_value >= thresholds:
-#                        msg = '[모델 학습 완료] ' + metric +'이 설정하신 thresolds: ' + str(thresholds) + '를 초과하였습니다.'
-#                        response = WebClient(token=token).chat_postMessage(channel=channel_id, text=msg)
-#                except SlackApiError as e:
-#                    assert e.response["error"]
-#            elif message is not None:
-#                try:
-#                    msg = message
-#                    response = WebClient(token=token).chat_postMessage(channel=channel_id, text=msg)
-#                except SlackApiError as e:
-#                    assert e.response["error"]
-#            else:
-#                pass
-
     def off_autolog():
         def stop_log(self, original, args, kwargs, unlogged_params):
             fit_model = original(self, *args, **kwargs)
