@@ -1,19 +1,14 @@
-import os
 import logging
 
-logging.basicConfig(level = logging.INFO, format = '%(message)s')
+logging.basicConfig(level=logging.INFO, format='%(message)s')
 
-def setAPI(api_url, api_port):
-    
+
+def set_api(api_url, api_port):
     editList = ["BACK_END_API_URL = '{}'".format(api_url), 
                 '\n',
                 "BACK_END_API_PORT = '{}'".format(api_port)]
     
-    LcConst_path = '/opt/conda/lib/python3.7/site-packages/Accuinsight/modeler/core/LcConst/LcConst.py'
-    if os.path.isfile(LcConst_path) == False:
-            LcConst_path = '/opt/conda/lib/python3.6/site-packages/Accuinsight/modeler/core/LcConst/LcConst.py'
-    else:
-        pass
+    LcConst_path = '/usr/lib/modeler-python-package/Accuinsight/modeler/core/LcConst/LcConst.py'   # 수정 필요
     
     with open(LcConst_path, 'r+') as f:
         new_f = f.readlines()
