@@ -6,13 +6,13 @@ from slack_sdk.errors import SlackApiError
 
 logging.basicConfig(level=logging.DEBUG)
 
+
 class AbcNotifier:
     def completed_message(self, **kwargs):
         pass
 
 
 class SlackApp(AbcNotifier):
-
     def setData(self, token, channel_id):
         self.token = token
         self.channel_id = channel_id
@@ -35,8 +35,6 @@ class SlackApp(AbcNotifier):
 
 
 def load_model(run_name):
-
-
     k = []
     best_model_path_dict = dict()
 
@@ -70,7 +68,7 @@ def load_model(run_name):
         json_file.close()
         loaded_model = model_from_json(loaded_model_json)
 
-        #load weights into new model
+        # load weights into new model
         loaded_model.load_weights(best_model_path_dict['h5'])
 
     # load model trained using tensorflow
@@ -82,12 +80,11 @@ def load_model(run_name):
         json_file.close()
         loaded_model = model_from_json(loaded_model_json)
 
-        #load weights into new model
+        # load weights into new model
         loaded_model.load_weights(best_model_path_dict['h5'])
 
     else:
         import joblib
         loaded_model = joblib.load(best_model_path_dict['joblib'])
 
-
-    return(loaded_model)
+    return loaded_model
