@@ -3,6 +3,7 @@ import subprocess
 from Accuinsight.modeler.clients.modeler_api import WorkspaceRunRestApi
 from Accuinsight.modeler.entities.workspace_run_log import WorkspaceRunLog
 from Accuinsight.modeler.core.LcConst import LcConst
+from Accuinsight.modeler.utils.os_getenv import get_os_env
 
 
 class WorkspaceRun:
@@ -10,10 +11,12 @@ class WorkspaceRun:
         Object for running code and sending the result to backend.
     """
     def __init__(self):
+        env_value = get_os_env('ENV')
+
         self.workspace_run_log = WorkspaceRunLog()
-        self.workspace_run_api = WorkspaceRunRestApi(LcConst.BACK_END_API_URL,
-                                                     LcConst.BACK_END_API_PORT,
-                                                     LcConst.BACK_END_API_URI)
+        self.workspace_run_api = WorkspaceRunRestApi(env_value[LcConst.BACK_END_API_URL],
+                                                     env_value[LcConst.BACK_END_API_PORT],
+                                                     env_value[LcConst.BACK_END_API_URI])
         self.code_path = None
 
     def exec_code(self):
