@@ -196,13 +196,13 @@ def _make_feature_data(json_body):
     #json_path = run_result_path[RUN_MODEL_SHAP_JSON_PATH]
 
     #json_path = None
-    
+
     if RUN_MODEL_SHAP_JSON_PATH in run_result_path.keys():
         json_path = run_result_path[RUN_MODEL_SHAP_JSON_PATH]
-        
+
         with open(json_path) as json_file:
             shap_json_data = json.load(json_file)
-        json_body['feature']['importance'] = shap_json_data   
+        json_body['feature']['importance'] = shap_json_data
 
     return json_body
 
@@ -227,26 +227,25 @@ def call_endpoint(host_creds, endpoint, method, json_body, response_proto):
     return response_proto
 
 
-def key_clock(username, password):
-  headers = {'Content-Type': 'application/x-www-form-urlencoded'}
-  data = {'grant_type': 'password',
-          'client_id': 'accu_modeler_client',
-          'client_secret': '379668c7-70d2-49db-b977-d3c2b6baed14' ,
-          'username': username,
-          'password': password}
+#def key_clock(username, password):
+#  headers = {'Content-Type': 'application/x-www-form-urlencoded'}
+#  data = {'grant_type': 'password',
+#          'client_id': 'accu_modeler_client',
+#          'client_secret': '379668c7-70d2-49db-b977-d3c2b6baed14' ,
+#          'username': username,
+#          'password': password}
+#  try:
+#    response = requests.post('https://sso.aws-multiverse.skcc.com/auth/realms/DOTS/protocol/openid-connect/token', data, headers=headers)
+#
+#  except Exception:
+#    logging.error("key_clock server connection failed")
+#    response = None
+#
+#  return response
+
+def daapi_list(host, api, token):
   try:
-    response = requests.post('https://sso.aws-multiverse.skcc.com/auth/realms/DOTS/protocol/openid-connect/token', data, headers=headers)
-
-  except Exception:
-    logging.error("key_clock server connection failed")
-    response = None
-
-  return response
-
-def daapi_list(host, api, username, password):
-  try:
-    token =  key_clock(usernamehashlib.py, password)
-    headers = {'x-auth-token': token.json()["access_token"]}
+    headers = {'x-auth-token': token}
     response = requests.get(host+api, headers=headers)
     result = response.json()["data"]
 
@@ -256,10 +255,9 @@ def daapi_list(host, api, username, password):
 
   return result
 
-def daapi_data_list(host, api, username, password, data):
+def daapi_data_list(host, api, data, token):
   try:
-    token =  key_clock(username, password)
-    headers = {'x-auth-token': token.json()["access_token"]}
+    headers = {'x-auth-token': token}
     response = requests.get(host+api, data, headers=headers)
     result = response.json()["data"]
 
